@@ -5,10 +5,7 @@ import bpy_extras.object_utils
 
 
 class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
-    abso_major_rad = None
-    ''' '''
-
-    abso_minor_rad = None
+    align_items = None
     ''' '''
 
     bl_idname = None
@@ -23,41 +20,14 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
     bl_rna = None
     ''' '''
 
-    generate_uvs = None
-    ''' '''
-
     id_data = None
     ''' '''
 
-    layers = None
-    ''' '''
+    def align_update_callback(self, _context):
+        ''' 
 
-    location = None
-    ''' '''
-
-    major_radius = None
-    ''' '''
-
-    major_segments = None
-    ''' '''
-
-    minor_radius = None
-    ''' '''
-
-    minor_segments = None
-    ''' '''
-
-    mode = None
-    ''' '''
-
-    order = None
-    ''' '''
-
-    rotation = None
-    ''' '''
-
-    view_align = None
-    ''' '''
+        '''
+        pass
 
     def as_keywords(self, ignore):
         ''' 
@@ -71,7 +41,19 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -101,7 +83,7 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
-    def invoke(self, context, event):
+    def invoke(self, context, _event):
         ''' 
 
         '''
@@ -113,6 +95,12 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -149,7 +137,7 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
-    def mode_update_callback(self, context):
+    def mode_update_callback(self, _context):
         ''' 
 
         '''
@@ -173,6 +161,18 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -191,12 +191,6 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
-    def view_align_update_callback(self, context):
-        ''' 
-
-        '''
-        pass
-
 
 def add_torus(major_rad, minor_rad, major_seg, minor_seg):
     ''' 
