@@ -3,8 +3,6 @@ import typing
 import bpy_types
 import rna_prop_ui
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class MESH_MT_shape_key_context_menu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
@@ -2167,8 +2165,7 @@ class DATA_PT_normals(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         pass
 
 
-class DATA_PT_normals_auto_smooth(MeshButtonsPanel, bpy_types.Panel,
-                                  bpy_types._GenericUI):
+class DATA_PT_remesh(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
     COMPAT_ENGINES = None
     ''' '''
 
@@ -2178,7 +2175,7 @@ class DATA_PT_normals_auto_smooth(MeshButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
-    bl_parent_id = None
+    bl_options = None
     ''' '''
 
     bl_region_type = None
@@ -2223,12 +2220,6 @@ class DATA_PT_normals_auto_smooth(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
-    def draw_header(self, context):
-        ''' 
-
-        '''
-        pass
-
     def driver_add(self):
         ''' 
 
@@ -2362,7 +2353,8 @@ class DATA_PT_normals_auto_smooth(MeshButtonsPanel, bpy_types.Panel,
         pass
 
 
-class DATA_PT_remesh(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
+class DATA_PT_sculpt_vertex_colors(MeshButtonsPanel, bpy_types.Panel,
+                                   bpy_types._GenericUI):
     COMPAT_ENGINES = None
     ''' '''
 
