@@ -3,7 +3,13 @@ import typing
 import bpy_types
 
 
-class TIME_HT_header(bpy_types.Header, bpy_types._GenericUI):
+class TIME_HT_editor_buttons(bpy_types.Header, bpy_types._GenericUI):
+    bl_idname = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
     bl_rna = None
     ''' '''
 
@@ -25,12 +31,30 @@ class TIME_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
         '''
         pass
 
+    def draw_header(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -61,6 +85,12 @@ class TIME_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -109,157 +139,7 @@ class TIME_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class TIME_MT_autokey(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
+    def pop(self):
         ''' 
 
         '''
@@ -271,6 +151,12 @@ class TIME_MT_autokey(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -318,6 +204,18 @@ class TIME_MT_cache(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -330,7 +228,7 @@ class TIME_MT_cache(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -366,6 +264,12 @@ class TIME_MT_cache(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -409,7 +313,7 @@ class TIME_MT_cache(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -421,12 +325,24 @@ class TIME_MT_cache(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -477,6 +393,18 @@ class TIME_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -489,13 +417,7 @@ class TIME_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_menus(self, layout, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -531,6 +453,12 @@ class TIME_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -574,7 +502,7 @@ class TIME_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -586,157 +514,7 @@ class TIME_MT_editor_menus(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class TIME_MT_frame(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
+    def pop(self):
         ''' 
 
         '''
@@ -748,6 +526,12 @@ class TIME_MT_frame(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -795,6 +579,18 @@ class TIME_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -807,7 +603,7 @@ class TIME_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -843,6 +639,12 @@ class TIME_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -886,7 +688,7 @@ class TIME_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -898,157 +700,7 @@ class TIME_MT_marker(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class TIME_MT_playback(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
+    def pop(self):
         ''' 
 
         '''
@@ -1060,6 +712,12 @@ class TIME_MT_playback(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1107,6 +765,18 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1119,7 +789,7 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -1155,6 +825,12 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1198,7 +874,7 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -1210,12 +886,24 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1241,7 +929,390 @@ class TIME_MT_view(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-def marker_menu_generic(layout):
+class TimelinePanelButtons:
+    bl_region_type = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    def has_timeline(self, context):
+        ''' 
+
+        '''
+        pass
+
+
+class TIME_PT_keyframing_settings(TimelinePanelButtons, bpy_types.Panel,
+                                  bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def has_timeline(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class TIME_PT_playback(TimelinePanelButtons, bpy_types.Panel,
+                       bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def has_timeline(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+def marker_menu_generic(layout, context):
     ''' 
 
     '''
