@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class TOPBAR_HT_upper_bar(bpy_types.Header, bpy_types._GenericUI):
     bl_rna = None
@@ -370,378 +368,6 @@ class TOPBAR_MT_app(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class TOPBAR_MT_app_about(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass_py(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, _context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, _context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_overridable_library(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name, add_operator):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def pop(self):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_overridable_library_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class TOPBAR_MT_app_support(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass_py(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, _context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, _context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_overridable_library(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name, add_operator):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def pop(self):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_overridable_library_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
 class TOPBAR_MT_app_system(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
