@@ -2,8 +2,6 @@ import sys
 import typing
 import bmesh.types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def edge_rotate(edge: 'bmesh.types.BMEdge',
                 ccw: bool = False) -> 'bmesh.types.BMEdge':
@@ -13,7 +11,6 @@ def edge_rotate(edge: 'bmesh.types.BMEdge',
     :type edge: 'bmesh.types.BMEdge'
     :param ccw: When True the edge will be rotated counter clockwise.
     :type ccw: bool
-    :rtype: 'bmesh.types.BMEdge'
     :return: The newly rotated edge.
     '''
 
@@ -21,7 +18,7 @@ def edge_rotate(edge: 'bmesh.types.BMEdge',
 
 
 def edge_split(edge: 'bmesh.types.BMEdge', vert: 'bmesh.types.BMVert',
-               fac: float) -> typing.Tuple:
+               fac: float) -> tuple:
     ''' Split an edge, return the newly created data.
 
     :param edge: The edge to split.
@@ -30,7 +27,6 @@ def edge_split(edge: 'bmesh.types.BMEdge', vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param fac: The point on the edge where the new vert will be created [0 - 1].
     :type fac: float
-    :rtype: typing.Tuple
     :return: The newly created (edge, vert) pair.
     '''
 
@@ -55,7 +51,6 @@ def face_join(faces: 'bmesh.types.BMFace',
     :type faces: 'bmesh.types.BMFace'
     :param remove: Remove the edges and vertices between the faces.
     :type remove: bool
-    :rtype: 'bmesh.types.BMFace'
     :return: The newly created face or None on failure.
     '''
 
@@ -82,7 +77,6 @@ def face_split(face: 'bmesh.types.BMFace',
     :type use_exist: bool
     :param example: Newly created edge will copy settings from this one.
     :type example: 'bmesh.types.BMEdge'
-    :rtype: 'bmesh.types.BMLoop'
     :return: The newly created face or None on failure.
     '''
 
@@ -99,7 +93,6 @@ def face_split_edgenet(face: 'bmesh.types.BMFace',
     :type face: 'bmesh.types.BMFace'
     :param edgenet: Sequence of edges.
     :type edgenet: 'bmesh.types.BMEdge'
-    :rtype: 'bmesh.types.BMFace'
     :return: The newly created faces.
     '''
 
@@ -114,7 +107,6 @@ def face_vert_separate(face: 'bmesh.types.BMFace',
     :type face: 'bmesh.types.BMFace'
     :param vert: A vertex in the face to separate.
     :type vert: 'bmesh.types.BMVert'
-    :rtype: 'bmesh.types.BMVert'
     :return: The newly created vertex or None on failure.
     '''
 
@@ -126,7 +118,6 @@ def loop_separate(loop: 'bmesh.types.BMLoop') -> 'bmesh.types.BMVert':
 
     :param loop: The loop to separate.
     :type loop: 'bmesh.types.BMLoop'
-    :rtype: 'bmesh.types.BMVert'
     :return: The newly created vertex or None on failure.
     '''
 
@@ -141,7 +132,6 @@ def vert_collapse_edge(vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param edge: The edge to collapse into.
     :type edge: 'bmesh.types.BMEdge'
-    :rtype: 'bmesh.types.BMEdge'
     :return: The resulting edge from the collapse operation.
     '''
 
@@ -158,7 +148,6 @@ def vert_collapse_faces(vert: 'bmesh.types.BMVert', edge: 'bmesh.types.BMEdge',
     :type edge: 'bmesh.types.BMEdge'
     :param fac: The factor to use when merging customdata [0 - 1].
     :type fac: float
-    :rtype: 'bmesh.types.BMEdge'
     :return: The resulting edge from the collapse operation.
     '''
 
@@ -170,7 +159,6 @@ def vert_dissolve(vert: 'bmesh.types.BMVert') -> bool:
 
     :param vert: The vert to be dissolved.
     :type vert: 'bmesh.types.BMVert'
-    :rtype: bool
     :return: True when the vertex dissolve is successful.
     '''
 
@@ -185,7 +173,6 @@ def vert_separate(vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param edges: The edges to separated.
     :type edges: 'bmesh.types.BMEdge'
-    :rtype: 'bmesh.types.BMVert'
     :return: The newly separated verts (including the vertex passed).
     '''
 
