@@ -1,11 +1,10 @@
 import sys
 import typing
-from . import icons
-from . import handlers
-from . import timers
 from . import translations
+from . import handlers
+from . import icons
+from . import timers
 
-GenericType = typing.TypeVar("GenericType")
 alembic = None
 ''' constant value bpy.app.alembic(supported=True, version=(1, 7, 12), version_string=' 1, 7, 12')
 '''
@@ -167,7 +166,7 @@ factory_startup = None
 '''
 
 ffmpeg = None
-''' constant value bpy.app.ffmpeg(supported=True, avcodec_version=(58, 18, 100), avcodec_version_string='58, 18, 100', avdevice_version=(58, 3, 100), avdevice_version_string='58, 3, 100', avformat_version=(58, 12, 100), avformat_version_string='58, 12, 100', avutil_version=(56, 14, 100), avutil_version_string='56, 14, 100', swscale_version=(5, 1, 100), swscale_version_string=' 5, 1, 100')
+''' constant value bpy.app.ffmpeg(supported=True, avcodec_version=(58, 54, 100), avcodec_version_string='58, 54, 100', avdevice_version=(58, 8, 100), avdevice_version_string='58, 8, 100', avformat_version=(58, 29, 100), avformat_version_string='58, 29, 100', avutil_version=(56, 31, 100), avutil_version_string='56, 31, 100', swscale_version=(5, 5, 100), swscale_version_string=' 5, 5, 100')
 '''
 
 handlers = None
@@ -179,11 +178,11 @@ icons = None
 '''
 
 ocio = None
-''' constant value bpy.app.ocio(supported=True, version=(1, 1, 0), version_string=' 1, 1, 0')
+''' constant value bpy.app.ocio(supported=True, version=(1, 1, 1), version_string=' 1, 1, 1')
 '''
 
 oiio = None
-''' constant value bpy.app.oiio(supported=True, version=(1, 8, 13), version_string=' 1, 8, 13')
+''' constant value bpy.app.oiio(supported=True, version=(2, 1, 15), version_string=' 2, 1, 15')
 '''
 
 opensubdiv = None
@@ -219,17 +218,13 @@ translations = None
 '''
 
 usd = None
-''' constant value bpy.app.usd(supported=True, version=(0, 19, 11), version_string=' 0, 19, 11')
+''' constant value bpy.app.usd(supported=True, version=(0, 20, 5), version_string=' 0, 20, 5')
 '''
 
 use_event_simulate = None
 ''' Boolean, for application behavior (started with --enable-* matching this attribute name)
 '''
 
-use_override_library = None
-''' Boolean, whether library override is exposed in UI or not.
-'''
-
 use_userpref_skip_save_on_exit = None
 ''' Boolean, for application behavior (started with --enable-* matching this attribute name)
 '''
