@@ -1,14 +1,11 @@
 import sys
 import typing
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def locale_explode(locale):
     ''' Return all components and their combinations of the given ISO locale string. >>> bpy.app.translations.locale_explode("sr_RS@latin") ("sr", "RS", "latin", "sr_RS", "sr@latin") For non-complete locales, missing elements will be None.
 
     :type msgid: str
-    :param locale:  The ISO locale string to explode.
     '''
 
     pass
@@ -62,13 +59,13 @@ def pgettext_tip(msgid: str, msgctxt: str = None):
     pass
 
 
-def register(module_name: str, translations_dict: typing.Dict):
+def register(module_name: str, translations_dict: dict):
     ''' Registers an addon's UI translations.
 
     :param module_name: The name identifying the addon.
     :type module_name: str
     :param translations_dict: {locale: {msg_key: msg_translation, ...}, ...}
-    :type translations_dict: typing.Dict
+    :type translations_dict: dict
     '''
 
     pass
