@@ -82,6 +82,8 @@ gpencil_data: 'bpy.types.GreasePencil' = None
 
 gpencil_data_owner: 'bpy.types.ID' = None
 
+hair: 'bpy.types.Hair' = None
+
 image_paint_object: 'bpy.types.Object' = None
 
 lattice: 'bpy.types.Lattice' = None
@@ -102,7 +104,7 @@ mesh: 'bpy.types.Mesh' = None
 
 meta_ball: 'bpy.types.MetaBall' = None
 
-mode: typing.Union[str, int] = None
+mode: typing.Union[int, str] = None
 
 object: 'bpy.types.Object' = None
 
@@ -118,6 +120,8 @@ particle_system: 'bpy.types.ParticleSystem' = None
 
 particle_system_editable: 'bpy.types.ParticleSystem' = None
 
+pointcloud: 'bpy.types.PointCloud' = None
+
 pose_bone: 'bpy.types.PoseBone' = None
 
 pose_object: 'bpy.types.Object' = None
