@@ -1,8 +1,6 @@
 import sys
 import typing
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def clear_by_owner(owner):
     ''' Clear all subscribers using this owner.
@@ -12,8 +10,8 @@ def clear_by_owner(owner):
     pass
 
 
-def publish_rna(data, owner, args, notify):
-    ''' Notify subscribers of changes to this property (this typically doesn't need to be called explicitly since changes will automatically publish updates). In some cases it may be useful to publish changes explicitly using more general keys.
+def publish_rna(key):
+    ''' 
 
     :param key: Represents the type of data being subscribed to Arguments include - bpy.types.Property instance. - bpy.types.Struct type. - ( bpy.types.Struct , str) type and property name.
     '''
@@ -21,13 +19,13 @@ def publish_rna(data, owner, args, notify):
     pass
 
 
-def subscribe_rna(data, owner, args, notify, options: typing.Set = 'set()'):
+def subscribe_rna(key, owner, args, notify, options: set = 'set()'):
     ''' 
 
     :param key: Represents the type of data being subscribed to Arguments include - bpy.types.Property instance. - bpy.types.Struct type. - ( bpy.types.Struct , str) type and property name.
     :param owner: Handle for this subscription (compared by identity).
     :param options: Change the behavior of the subscriber. - PERSISTENT when set, the subscriber will be kept when remapping ID data.
-    :type options: typing.Set
+    :type options: set
     '''
 
     pass
