@@ -1,16 +1,8 @@
 import sys
 import typing
-import bpy.types
-
-GenericType = typing.TypeVar("GenericType")
 
 
-def open(override_context: typing.Union[typing.
-                                        Dict, 'bpy.types.Context'] = None,
-         execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
-         *,
-         filepath: str = "",
+def open(filepath: str = "",
          hide_props_region: bool = True,
          check_existing: bool = True,
          filter_blender: bool = False,
@@ -30,13 +22,10 @@ def open(override_context: typing.Union[typing.
          filter_folder: bool = True,
          filter_blenlib: bool = False,
          filemode: int = 8,
-         display_type: typing.Union[str, int] = 'DEFAULT',
-         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+         display_type: typing.Union[int, str] = 'DEFAULT',
+         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Load a cache file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -78,23 +67,17 @@ def open(override_context: typing.Union[typing.
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
 
 
-def reload(override_context: typing.Union[typing.
-                                          Dict, 'bpy.types.Context'] = None,
-           execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+def reload():
     ''' Update objects paths list with new data from the archive
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
