@@ -1,28 +1,17 @@
 import sys
 import typing
-import bpy.types
-
-GenericType = typing.TypeVar("GenericType")
 
 
-def bvh(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def bvh(filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.bvh",
         global_scale: float = 1.0,
         frame_start: int = 0,
         frame_end: int = 0,
-        rotate_mode: typing.Union[str, int] = 'NATIVE',
+        rotate_mode: typing.Union[int, str] = 'NATIVE',
         root_transform_only: bool = False):
     ''' Save a BVH motion capture file from an armature
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -36,7 +25,7 @@ def bvh(override_context: typing.Union[typing.
     :param frame_end: End Frame, End frame to export
     :type frame_end: int
     :param rotate_mode: Rotation, Rotation conversion * NATIVE Euler (Native), Use the rotation order defined in the BVH file. * XYZ Euler (XYZ), Convert rotations to euler XYZ. * XZY Euler (XZY), Convert rotations to euler XZY. * YXZ Euler (YXZ), Convert rotations to euler YXZ. * YZX Euler (YZX), Convert rotations to euler YZX. * ZXY Euler (ZXY), Convert rotations to euler ZXY. * ZYX Euler (ZYX), Convert rotations to euler ZYX.
-    :type rotate_mode: typing.Union[str, int]
+    :type rotate_mode: typing.Union[int, str]
     :param root_transform_only: Root Translation Only, Only write out translation channels for the root bone
     :type root_transform_only: bool
     '''
