@@ -2,20 +2,13 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
 
-
-def fbx(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def fbx(filepath: str = "",
         directory: str = "",
         filter_glob: str = "*.fbx",
-        files: bpy.types.
-        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
-        ui_tab: typing.Union[str, int] = 'MAIN',
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
+        ui_tab: typing.Union[int, str] = 'MAIN',
         use_manual_orientation: bool = False,
         global_scale: float = 1.0,
         bake_space_transform: bool = False,
@@ -31,16 +24,13 @@ def fbx(override_context: typing.Union[typing.
         ignore_leaf_bones: bool = False,
         force_connect_children: bool = False,
         automatic_bone_orientation: bool = False,
-        primary_bone_axis: typing.Union[str, int] = 'Y',
-        secondary_bone_axis: typing.Union[str, int] = 'X',
+        primary_bone_axis: typing.Union[int, str] = 'Y',
+        secondary_bone_axis: typing.Union[int, str] = 'X',
         use_prepost_rot: bool = True,
-        axis_forward: typing.Union[str, int] = '-Z',
-        axis_up: typing.Union[str, int] = 'Y'):
+        axis_forward: typing.Union[int, str] = '-Z',
+        axis_up: typing.Union[int, str] = 'Y'):
     ''' Load a FBX file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param directory: directory
@@ -48,16 +38,16 @@ def fbx(override_context: typing.Union[typing.
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param ui_tab: ui_tab, Import options categories * MAIN Main, Main basic settings. * ARMATURE Armatures, Armature-related settings.
-    :type ui_tab: typing.Union[str, int]
+    :type ui_tab: typing.Union[int, str]
     :param use_manual_orientation: Manual Orientation, Specify orientation and scale, instead of using embedded data in FBX file
     :type use_manual_orientation: bool
     :param global_scale: Scale
     :type global_scale: float
-    :param bake_space_transform: !EXPERIMENTAL! Apply Transform, Bake space transform into object data, avoids getting unwanted rotations to objects when target space is not aligned with Blender's space (WARNING! experimental option, use at own risks, known broken with armatures/animations)
+    :param bake_space_transform: Apply Transform, Bake space transform into object data, avoids getting unwanted rotations to objects when target space is not aligned with Blender's space (WARNING! experimental option, use at own risks, known broken with armatures/animations)
     :type bake_space_transform: bool
-    :param use_custom_normals: Import Normals, Import custom normals, if available (otherwise Blender will recompute them)
+    :param use_custom_normals: Custom Normals, Import custom normals, if available (otherwise Blender will recompute them)
     :type use_custom_normals: bool
     :param use_image_search: Image Search, Search subdirs for any associated images (WARNING: may be slow)
     :type use_image_search: bool
@@ -69,9 +59,9 @@ def fbx(override_context: typing.Union[typing.
     :type use_anim: bool
     :param anim_offset: Animation Offset, Offset to apply to animation during import, in frames
     :type anim_offset: float
-    :param use_subsurf: Import Subdivision Surface, Import FBX subdivision information as subdivision surface modifiers
+    :param use_subsurf: Subdivision Data, Import FBX subdivision information as subdivision surface modifiers
     :type use_subsurf: bool
-    :param use_custom_props: Import User Properties, Import user properties as custom properties
+    :param use_custom_props: Custom Properties, Import user properties as custom properties
     :type use_custom_props: bool
     :param use_custom_props_enum_as_string: Import Enums As Strings, Store enumeration values as strings
     :type use_custom_props_enum_as_string: bool
@@ -82,53 +72,48 @@ def fbx(override_context: typing.Union[typing.
     :param automatic_bone_orientation: Automatic Bone Orientation, Try to align the major bone axis with the bone children
     :type automatic_bone_orientation: bool
     :param primary_bone_axis: Primary Bone Axis
-    :type primary_bone_axis: typing.Union[str, int]
+    :type primary_bone_axis: typing.Union[int, str]
     :param secondary_bone_axis: Secondary Bone Axis
-    :type secondary_bone_axis: typing.Union[str, int]
+    :type secondary_bone_axis: typing.Union[int, str]
     :param use_prepost_rot: Use Pre/Post Rotation, Use pre/post rotation from FBX transform (you may have to disable that in some cases)
     :type use_prepost_rot: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[str, int]
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up
-    :type axis_up: typing.Union[str, int]
+    :type axis_up: typing.Union[int, str]
     '''
 
     pass
 
 
-def gltf(override_context: typing.Union[typing.
-                                        Dict, 'bpy.types.Context'] = None,
-         execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
-         *,
-         filepath: str = "",
+def gltf(filepath: str = "",
          filter_glob: str = "*.glb;*.gltf",
-         files: bpy.types.
-         bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          loglevel: int = 0,
          import_pack_images: bool = True,
-         import_shading: typing.Union[str, int] = 'NORMALS',
-         bone_heuristic: typing.Union[str, int] = 'TEMPERANCE',
+         merge_vertices: bool = False,
+         import_shading: typing.Union[int, str] = 'NORMALS',
+         bone_heuristic: typing.Union[int, str] = 'TEMPERANCE',
          guess_original_bind_pose: bool = True):
     ''' Load a glTF 2.0 file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param loglevel: Log Level, Log Level
     :type loglevel: int
     :param import_pack_images: Pack Images, Pack all images into .blend file
     :type import_pack_images: bool
+    :param merge_vertices: Merge Vertices, The glTF format requires discontinuous normals, UVs, and other vertex attributes to be stored as separate vertices, as required for rendering on typical graphics hardware. This option attempts to combine co-located vertices where possible. Currently cannot combine verts with different normals
+    :type merge_vertices: bool
     :param import_shading: Shading, How normals are computed during import
-    :type import_shading: typing.Union[str, int]
+    :type import_shading: typing.Union[int, str]
     :param bone_heuristic: Bone Dir, Heuristic for placing bones. Tries to make bones pretty * BLENDER Blender (best for re-importing), Good for re-importing glTFs exported from Blender. Bone tips are placed on their local +Y axis (in glTF space). * TEMPERANCE Temperance (average), Decent all-around strategy. A bone with one child has its tip placed on the local axis closest to its child. * FORTUNE Fortune (may look better, less accurate), Might look better than Temperance, but also might have errors. A bone with one child has its tip placed at its child's root. Non-uniform scalings may get messed up though, so beware.
-    :type bone_heuristic: typing.Union[str, int]
+    :type bone_heuristic: typing.Union[int, str]
     :param guess_original_bind_pose: Guess Original Bind Pose, Try to guess the original bind pose for skinned meshes from the inverse bind matrices. When off, use default/rest pose as bind pose
     :type guess_original_bind_pose: bool
     '''
@@ -136,12 +121,7 @@ def gltf(override_context: typing.Union[typing.
     pass
 
 
-def obj(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def obj(filepath: str = "",
         filter_glob: str = "*.obj;*.mtl",
         use_edges: bool = True,
         use_smooth_groups: bool = True,
@@ -149,15 +129,12 @@ def obj(override_context: typing.Union[typing.
         use_split_groups: bool = False,
         use_groups_as_vgroups: bool = False,
         use_image_search: bool = True,
-        split_mode: typing.Union[str, int] = 'ON',
+        split_mode: typing.Union[int, str] = 'ON',
         global_clight_size: float = 0.0,
-        axis_forward: typing.Union[str, int] = '-Z',
-        axis_up: typing.Union[str, int] = 'Y'):
+        axis_forward: typing.Union[int, str] = '-Z',
+        axis_up: typing.Union[int, str] = 'Y'):
     ''' Load a Wavefront OBJ File
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
@@ -175,40 +152,32 @@ def obj(override_context: typing.Union[typing.
     :param use_image_search: Image Search, Search subdirs for any associated images (Warning, may be slow)
     :type use_image_search: bool
     :param split_mode: Split * ON Split, Split geometry, omits unused verts. * OFF Keep Vert Order, Keep vertex order from file.
-    :type split_mode: typing.Union[str, int]
+    :type split_mode: typing.Union[int, str]
     :param global_clight_size: Clamp Size, Clamp bounds under this value (zero to disable)
     :type global_clight_size: float
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[str, int]
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up
-    :type axis_up: typing.Union[str, int]
+    :type axis_up: typing.Union[int, str]
     '''
 
     pass
 
 
-def x3d(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def x3d(filepath: str = "",
         filter_glob: str = "*.x3d;*.wrl",
-        axis_forward: typing.Union[str, int] = 'Z',
-        axis_up: typing.Union[str, int] = 'Y'):
+        axis_forward: typing.Union[int, str] = 'Z',
+        axis_up: typing.Union[int, str] = 'Y'):
     ''' Import an X3D or VRML2 file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[str, int]
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up
-    :type axis_up: typing.Union[str, int]
+    :type axis_up: typing.Union[int, str]
     '''
 
     pass
