@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def abspath(path,
             start: typing.Union[bytes, str] = None,
@@ -81,14 +79,13 @@ def is_subdir(path: typing.Union[bytes, str], directory):
     pass
 
 
-def module_names(path: str, recursive: bool = False) -> typing.List:
+def module_names(path: str, recursive: bool = False) -> list:
     ''' Return a list of modules which can be imported from *path*.
 
     :param path: a directory to scan.
     :type path: str
     :param recursive: Also return submodule names for packages.
     :type recursive: bool
-    :rtype: typing.List
     :return: a list of string pairs (module_name, module_file).
     '''
 
@@ -103,12 +100,11 @@ def native_pathsep(path):
     pass
 
 
-def reduce_dirs(dirs: typing.List) -> typing.List:
+def reduce_dirs(dirs: list) -> list:
     ''' Given a sequence of directories, remove duplicates and any directories nested in one of the other paths. (Useful for recursive path searching).
 
     :param dirs: Sequence of directory paths.
-    :type dirs: typing.List
-    :rtype: typing.List
+    :type dirs: list
     :return: A unique list of paths.
     '''
 
