@@ -1,8 +1,6 @@
 import sys
 import typing
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def to_string(unit_system: str,
               unit_category: str,
@@ -10,7 +8,7 @@ def to_string(unit_system: str,
               precision: int = 3,
               split_unit: bool = False,
               compatible_unit: bool = False) -> str:
-    ''' Convert a given input float value into a string with units. :raises ValueError: if conversion fails to generate a valid python string.
+    ''' Convert a given input float value into a string with units.
 
     :param unit_system: bpy.utils.units.systems .
     :type unit_system: str
@@ -24,7 +22,6 @@ def to_string(unit_system: str,
     :type split_unit: bool
     :param compatible_unit: Whether to use keyboard-friendly units (1m2) or nicer utf-8 ones (1m²).
     :type compatible_unit: bool
-    :rtype: str
     :return: The converted string.
     '''
 
@@ -35,7 +32,7 @@ def to_value(unit_system: str,
              unit_category: str,
              str_input: str,
              str_ref_unit: str = None) -> float:
-    ''' Convert a given input string into a float value. :raises ValueError: if conversion fails to generate a valid python float value.
+    ''' Convert a given input string into a float value.
 
     :param unit_system: bpy.utils.units.systems .
     :type unit_system: str
@@ -45,7 +42,6 @@ def to_value(unit_system: str,
     :type str_input: str
     :param str_ref_unit: A reference string from which to extract a default unit, if none is found in str_input .
     :type str_ref_unit: str
-    :rtype: float
     :return: The converted/interpreted value.
     '''
 
