@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def load_image(imagepath,
                dirname: str = '',
@@ -34,7 +32,6 @@ def load_image(imagepath,
     :type check_existing: bool
     :param force_reload: If true, force reloading of image (only useful when check_existing is also enabled).
     :type force_reload: bool
-    :rtype: 'bpy.types.Image'
     :return: an image or None
     '''
 
