@@ -1,9 +1,8 @@
 import sys
 import typing
+import bpy.types
 import mathutils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class AdjacencyIterator:
     ''' Class hierarchy: Iterator > AdjacencyIterator Class for representing adjacency iterators used in the chaining process. An AdjacencyIterator is created in the increment() and decrement() methods of a ChainingIterator and passed to the traverse() method of the ChainingIterator.
@@ -254,11 +253,11 @@ class Curve:
         '''
         pass
 
-    def __init__(self, brother: 'Curve'):
+    def __init__(self, brother: 'bpy.types.Curve'):
         ''' Copy Constructor.
 
         :param brother: A Curve object.
-        :type brother: 'Curve'
+        :type brother: 'bpy.types.Curve'
         '''
         pass
 
@@ -270,19 +269,19 @@ class Curve:
         '''
         pass
 
-    def push_vertex_back(self, vertex: 'SVertex'):
+    def push_vertex_back(self, vertex: typing.Union['SVertex', 'CurvePoint']):
         ''' Adds a single vertex at the end of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: 'SVertex'
+        :type vertex: typing.Union['SVertex', 'CurvePoint']
         '''
         pass
 
-    def push_vertex_front(self, vertex: 'SVertex'):
+    def push_vertex_front(self, vertex: typing.Union['SVertex', 'CurvePoint']):
         ''' Adds a single vertex at the front of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: 'SVertex'
+        :type vertex: typing.Union['SVertex', 'CurvePoint']
         '''
         pass
 
@@ -506,16 +505,16 @@ class FEdgeSharp:
     :type: int
     '''
 
-    material_left: 'Material' = None
+    material_left: 'bpy.types.Material' = None
     ''' The material of the face lying on the left of the FEdge.
 
-    :type: 'Material'
+    :type: 'bpy.types.Material'
     '''
 
-    material_right: 'Material' = None
+    material_right: 'bpy.types.Material' = None
     ''' The material of the face lying on the right of the FEdge. If this FEdge is a border, it has no Face on its right and therefore no material.
 
-    :type: 'Material'
+    :type: 'bpy.types.Material'
     '''
 
     normal_left: 'mathutils.Vector' = None
@@ -565,10 +564,10 @@ class FEdgeSmooth:
     :type: bool
     '''
 
-    material: 'Material' = None
+    material: 'bpy.types.Material' = None
     ''' The material of the face that this FEdge is running across.
 
-    :type: 'Material'
+    :type: 'bpy.types.Material'
     '''
 
     material_index: int = None
@@ -755,11 +754,12 @@ class Interface0DIterator:
         '''
         pass
 
-    def __init__(self, it: 'SVertexIterator'):
+    def __init__(self, it: typing.Union[
+            'CurvePointIterator', 'SVertexIterator', 'StrokeVertexIterator']):
         ''' Construct a nested Interface0DIterator that can be the argument of a Function0D.
 
         :param it: An iterator object to be nested.
-        :type it: 'SVertexIterator'
+        :type it: typing.Union['CurvePointIterator', 'SVertexIterator', 'StrokeVertexIterator']
         '''
         pass
 
@@ -934,30 +934,37 @@ class Material:
         '''
         pass
 
-    def __init__(self, brother: 'Material'):
+    def __init__(self, brother: 'bpy.types.Material'):
         ''' Copy constructor.
 
         :param brother: A Material object.
-        :type brother: 'Material'
+        :type brother: 'bpy.types.Material'
         '''
         pass
 
-    def __init__(self, line: 'mathutils.Vector', diffuse: 'mathutils.Vector',
-                 ambient: 'mathutils.Vector', specular: 'mathutils.Vector',
-                 emission: 'mathutils.Vector', shininess: float,
-                 priority: int):
+    def __init__(self, line: typing.Union[typing.List[float], typing.
+                                          List['mathutils.Vector']],
+                 diffuse: typing.Union[typing.List[float], typing.
+                                       List['mathutils.Vector']],
+                 ambient: typing.Union[typing.List[float], typing.
+                                       List['mathutils.Vector']],
+                 specular: typing.Union[typing.List[float], typing.
+                                        List['mathutils.Vector']],
+                 emission: typing.Union[typing.List[float], typing.
+                                        List['mathutils.Vector']],
+                 shininess: float, priority: int):
         ''' Builds a Material from its line, diffuse, ambient, specular, emissive colors, a shininess coefficient and line color priority.
 
         :param line: The line color.
-        :type line: 'mathutils.Vector'
+        :type line: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param diffuse: The diffuse color.
-        :type diffuse: 'mathutils.Vector'
+        :type diffuse: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param ambient: The ambient color.
-        :type ambient: 'mathutils.Vector'
+        :type ambient: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param specular: The specular color.
-        :type specular: 'mathutils.Vector'
+        :type specular: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param emission: The emissive color.
-        :type emission: 'mathutils.Vector'
+        :type emission: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
         :param shininess: The shininess coefficient.
         :type shininess: float
         :param priority: The line color priority.
@@ -981,7 +988,7 @@ class Nature:
 
 
 class Noise:
-    ''' Class to provide Perlin noise functionalities. Undocumented, consider contributing <https://developer.blender.org/T51061> __. Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+    ''' Class to provide Perlin noise functionalities.
     '''
 
     def __init__(self, seed=' -1'):
@@ -1002,21 +1009,21 @@ class Noise:
         '''
         pass
 
-    def smoothNoise2(self, v: 'mathutils.Vector') -> float:
+    def smoothNoise2(self, v: typing.List['mathutils.Vector']) -> float:
         ''' Returns a smooth noise value for a 2D element.
 
         :param v: Two-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :rtype: float
         :return: A smooth noise value.
         '''
         pass
 
-    def smoothNoise3(self, v: 'mathutils.Vector') -> float:
+    def smoothNoise3(self, v: typing.List['mathutils.Vector']) -> float:
         ''' Returns a smooth noise value for a 3D element.
 
         :param v: Three-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :rtype: float
         :return: A smooth noise value.
         '''
@@ -1040,14 +1047,14 @@ class Noise:
         pass
 
     def turbulence2(self,
-                    v: 'mathutils.Vector',
+                    v: typing.List['mathutils.Vector'],
                     freq: float,
                     amp: float,
                     oct: int = 4) -> float:
         ''' Returns a noise value for a 2D element.
 
         :param v: Two-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :param freq: Noise frequency.
         :type freq: float
         :param amp: Amplitude.
@@ -1060,14 +1067,14 @@ class Noise:
         pass
 
     def turbulence3(self,
-                    v: 'mathutils.Vector',
+                    v: typing.List['mathutils.Vector'],
                     freq: float,
                     amp: float,
                     oct: int = 4) -> float:
         ''' Returns a noise value for a 3D element.
 
         :param v: Three-dimensional sample point.
-        :type v: 'mathutils.Vector'
+        :type v: typing.List['mathutils.Vector']
         :param freq: Noise frequency.
         :type freq: float
         :param amp: Amplitude.
@@ -1387,10 +1394,10 @@ class SVertex:
     ''' Class hierarchy: Interface0D > SVertex Class to define a vertex of the embedding.
     '''
 
-    curvatures: typing.Tuple = None
+    curvatures: tuple = None
     ''' Curvature information expressed in the form of a seven-element tuple (K1, e1, K2, e2, Kr, er, dKr), where K1 and K2 are scalar values representing the first (maximum) and second (minimum) principal curvatures at this SVertex, respectively; e1 and e2 are three-dimensional vectors representing the first and second principal directions, i.e. the directions of the normal plane where the curvature takes its maximum and minimum values, respectively; and Kr, er and dKr are the radial curvature, radial direction, and the derivative of the radial curvature at this SVertex, respectively.
 
-    :type: typing.Tuple
+    :type: tuple
     '''
 
     id: 'Id' = None
@@ -1461,11 +1468,11 @@ class SVertex:
         '''
         pass
 
-    def add_normal(self, normal: 'mathutils.Vector'):
+    def add_normal(self, normal: typing.List['mathutils.Vector']):
         ''' Adds a normal to the SVertex's set of normals. If the same normal is already in the set, nothing changes.
 
         :param normal: A three-dimensional vector.
-        :type normal: 'mathutils.Vector'
+        :type normal: typing.List['mathutils.Vector']
         '''
         pass
 
@@ -1798,23 +1805,25 @@ class StrokeAttribute:
         '''
         pass
 
-    def set_attribute_vec2(self, name: str, value: 'mathutils.Vector'):
+    def set_attribute_vec2(self, name: str,
+                           value: typing.List['mathutils.Vector']):
         ''' Adds a user-defined attribute of two-dimensional vector type. If there is no attribute of the given name, it is added. Otherwise, the new value replaces the old one.
 
         :param name: The name of the attribute.
         :type name: str
         :param value: The attribute value.
-        :type value: 'mathutils.Vector'
+        :type value: typing.List['mathutils.Vector']
         '''
         pass
 
-    def set_attribute_vec3(self, name: str, value: 'mathutils.Vector'):
+    def set_attribute_vec3(self, name: str,
+                           value: typing.List['mathutils.Vector']):
         ''' Adds a user-defined attribute of three-dimensional vector type. If there is no attribute of the given name, it is added. Otherwise, the new value replaces the old one.
 
         :param name: The name of the attribute.
         :type name: str
         :param value: The attribute value.
-        :type value: 'mathutils.Vector'
+        :type value: typing.List['mathutils.Vector']
         '''
         pass
 
@@ -2635,10 +2644,10 @@ class ViewShape:
     :type: 'Id'
     '''
 
-    library_path: str = None
+    library_path: typing.Union[str, 'ViewShape'] = None
     ''' The library path of the ViewShape.
 
-    :type: str
+    :type: typing.Union[str, 'ViewShape']
     '''
 
     name: str = None
