@@ -2,13 +2,10 @@ import sys
 import typing
 import mathutils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def get_model_view_matrix() -> 'mathutils.Matrix':
     ''' Return a copy of the model-view matrix.
 
-    :rtype: 'mathutils.Matrix'
     :return: A 4x4 view matrix.
     '''
 
@@ -18,7 +15,6 @@ def get_model_view_matrix() -> 'mathutils.Matrix':
 def get_normal_matrix() -> 'mathutils.Matrix':
     ''' Return a copy of the normal matrix.
 
-    :rtype: 'mathutils.Matrix'
     :return: A 3x3 normal matrix.
     '''
 
@@ -28,7 +24,6 @@ def get_normal_matrix() -> 'mathutils.Matrix':
 def get_projection_matrix() -> 'mathutils.Matrix':
     ''' Return a copy of the projection matrix.
 
-    :rtype: 'mathutils.Matrix'
     :return: A 4x4 projection matrix.
     '''
 
@@ -46,7 +41,6 @@ def load_identity():
 def load_matrix(matrix: 'mathutils.Matrix'):
     ''' Load a matrix into the stack.
 
-    :param matrix: A 4x4 matrix.
     :type matrix: 'mathutils.Matrix'
     '''
 
@@ -56,7 +50,6 @@ def load_matrix(matrix: 'mathutils.Matrix'):
 def load_projection_matrix(matrix: 'mathutils.Matrix'):
     ''' Load a projection matrix into the stack.
 
-    :param matrix: A 4x4 matrix.
     :type matrix: 'mathutils.Matrix'
     '''
 
@@ -66,7 +59,6 @@ def load_projection_matrix(matrix: 'mathutils.Matrix'):
 def multiply_matrix(matrix: 'mathutils.Matrix'):
     ''' Multiply the current stack matrix.
 
-    :param matrix: A 4x4 matrix.
     :type matrix: 'mathutils.Matrix'
     '''
 
@@ -129,11 +121,10 @@ def reset():
     pass
 
 
-def scale(scale: typing.List):
+def scale(scale: list):
     ''' Scale the current stack matrix.
 
-    :param scale: Scale the current stack matrix.
-    :type scale: typing.List
+    :type scale: list
     '''
 
     pass
@@ -142,18 +133,16 @@ def scale(scale: typing.List):
 def scale_uniform(scale: float):
     ''' 
 
-    :param scale: Scale the current stack matrix.
     :type scale: float
     '''
 
     pass
 
 
-def translate(offset: typing.List):
+def translate(offset: list):
     ''' Scale the current stack matrix.
 
-    :param offset: Translate the current stack matrix.
-    :type offset: typing.List
+    :type offset: list
     '''
 
     pass
