@@ -1,12 +1,10 @@
 import sys
 import typing
-from . import kdtree
-from . import noise
 from . import interpolate
-from . import bvhtree
+from . import kdtree
 from . import geometry
-
-GenericType = typing.TypeVar("GenericType")
+from . import noise
+from . import bvhtree
 
 
 class Color:
@@ -31,10 +29,10 @@ class Color:
     :type: float
     '''
 
-    hsv: typing.Tuple[float] = None
+    hsv: float = None
     ''' HSV Values in [0, 1].
 
-    :type: typing.Tuple[float]
+    :type: float
     '''
 
     is_frozen: bool = None
@@ -92,114 +90,6 @@ class Color:
         '''
         pass
 
-    def __add__(self, other: 'Color') -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: 'Color'
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __sub__(self, other: 'Color') -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: 'Color'
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __mul__(self, other: typing.Union[int, float]) -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __truediv__(self, other: typing.Union[int, float]) -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __radd__(self, other: 'Color') -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: 'Color'
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __rsub__(self, other: 'Color') -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: 'Color'
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __rmul__(self, other: typing.Union[int, float]) -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __rtruediv__(self, other: typing.Union[int, float]) -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __iadd__(self, other: 'Color') -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: 'Color'
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __isub__(self, other: 'Color') -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: 'Color'
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __imul__(self, other: typing.Union[int, float]) -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Color'
-        '''
-        pass
-
-    def __itruediv__(self, other: typing.Union[int, float]) -> 'Color':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Color'
-        '''
-        pass
-
 
 class Euler:
     ''' This object gives access to Eulers in Blender. :param angles: Three angles, in radians. :type angles: 3d vector :param order: Optional order of the angles, a permutation of XYZ . :type order: str
@@ -266,11 +156,11 @@ class Euler:
         '''
         pass
 
-    def rotate(self, other: 'Euler'):
+    def rotate(self, other: typing.Union['Quaternion', 'Matrix', 'Euler']):
         ''' Rotates the euler by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: 'Euler'
+        :type other: typing.Union['Quaternion', 'Matrix', 'Euler']
         '''
         pass
 
@@ -427,8 +317,7 @@ class Matrix:
         pass
 
     @classmethod
-    def Scale(cls, factor: float, size: int,
-              axis: typing.Optional['Vector']) -> 'Matrix':
+    def Scale(cls, factor: float, size: int, axis: 'Vector') -> 'Matrix':
         ''' Create a matrix representing a scaling.
 
         :param factor: The factor of scaling to apply.
@@ -436,7 +325,7 @@ class Matrix:
         :param size: The size of the scale matrix to construct [2, 4].
         :type size: int
         :param axis: Direction to influence scale. (optional).
-        :type axis: typing.Optional['Vector']
+        :type axis: 'Vector'
         :rtype: 'Matrix'
         :return: A new scale matrix.
         '''
@@ -584,11 +473,11 @@ class Matrix:
         '''
         pass
 
-    def rotate(self, other: 'Euler'):
+    def rotate(self, other: typing.Union['Quaternion', 'Matrix', 'Euler']):
         ''' Rotates the matrix by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: 'Euler'
+        :type other: typing.Union['Quaternion', 'Matrix', 'Euler']
         '''
         pass
 
@@ -680,96 +569,6 @@ class Matrix:
         '''
         pass
 
-    def __add__(self, other: 'Matrix') -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __sub__(self, other: 'Matrix') -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __mul__(self, other: typing.Union[int, float]) -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __matmul__(self, other: 'Matrix') -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __radd__(self, other: 'Matrix') -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __rsub__(self, other: 'Matrix') -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __rmul__(self, other: typing.Union[int, float]) -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __rmatmul__(self, other: 'Matrix') -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __imul__(self, other: typing.Union[int, float]) -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Matrix'
-        '''
-        pass
-
-    def __imatmul__(self, other: 'Matrix') -> 'Matrix':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Matrix'
-        '''
-        pass
-
 
 class Quaternion:
     ''' This object gives access to Quaternions in Blender. :param seq: size 3 or 4 :type seq: Vector :param angle: rotation angle, in radians :type angle: float The constructor takes arguments in various forms: (), *no args* Create an identity quaternion (*wxyz*) Create a quaternion from a (w, x, y, z) vector. (*exponential_map*) Create a quaternion from a 3d exponential map vector. .. seealso:: :meth: to_exponential_map (*axis, angle*) Create a quaternion representing a rotation of *angle* radians over *axis*. .. seealso:: :meth: to_axis_angle
@@ -936,11 +735,11 @@ class Quaternion:
         '''
         pass
 
-    def rotate(self, other: 'Euler'):
+    def rotate(self, other: typing.Union['Quaternion', 'Matrix', 'Euler']):
         ''' Rotates the quaternion by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: 'Euler'
+        :type other: typing.Union['Quaternion', 'Matrix', 'Euler']
         '''
         pass
 
@@ -968,10 +767,10 @@ class Quaternion:
         '''
         pass
 
-    def to_axis_angle(self) -> 'Vector':
+    def to_axis_angle(self) -> typing.Union[float, 'Vector']:
         ''' Return the axis, angle representation of the quaternion.
 
-        :rtype: 'Vector'
+        :rtype: typing.Union[float, 'Vector']
         :return: axis, angle.
         '''
         pass
@@ -989,7 +788,7 @@ class Quaternion:
         pass
 
     def to_exponential_map(self) -> 'Vector':
-        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations. To convert back to a quaternion, pass it to the Quaternion constructor.
+        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations.
 
         :rtype: 'Vector'
         :return: exponential map.
@@ -1004,12 +803,12 @@ class Quaternion:
         '''
         pass
 
-    def to_swing_twist(self, axis) -> 'Quaternion':
+    def to_swing_twist(self, axis) -> typing.Union[float, 'Quaternion']:
         ''' Split the rotation into a swing quaternion with the specified axis fixed at zero, and the remaining twist rotation angle.
 
-        :param axis:  twist axis as a string in ['X', 'Y', 'Z']
+        :param axis: 
         :type axis: 
-        :rtype: 'Quaternion'
+        :rtype: typing.Union[float, 'Quaternion']
         :return: swing, twist angle.
         '''
         pass
@@ -1020,99 +819,6 @@ class Quaternion:
         '''
         pass
 
-    def __add__(self, other: 'Quaternion') -> 'Quaternion':
-        ''' 
-
-        :param other: 
-        :type other: 'Quaternion'
-        :rtype: 'Quaternion'
-        '''
-        pass
-
-    def __sub__(self, other: 'Quaternion') -> 'Quaternion':
-        ''' 
-
-        :param other: 
-        :type other: 'Quaternion'
-        :rtype: 'Quaternion'
-        '''
-        pass
-
-    def __mul__(self,
-                other: typing.Union[int, float, 'Quaternion']) -> 'Quaternion':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float, 'Quaternion']
-        :rtype: 'Quaternion'
-        '''
-        pass
-
-    def __matmul__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __radd__(self, other: 'Quaternion') -> 'Quaternion':
-        ''' 
-
-        :param other: 
-        :type other: 'Quaternion'
-        :rtype: 'Quaternion'
-        '''
-        pass
-
-    def __rsub__(self, other: 'Quaternion') -> 'Quaternion':
-        ''' 
-
-        :param other: 
-        :type other: 'Quaternion'
-        :rtype: 'Quaternion'
-        '''
-        pass
-
-    def __rmul__(self, other: typing.Union[int, float, 'Quaternion']
-                 ) -> 'Quaternion':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float, 'Quaternion']
-        :rtype: 'Quaternion'
-        '''
-        pass
-
-    def __rmatmul__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __imul__(self, other: typing.Union[int, float, 'Quaternion']
-                 ) -> 'Quaternion':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float, 'Quaternion']
-        :rtype: 'Quaternion'
-        '''
-        pass
-
-    def __imatmul__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
 
 class Vector:
     ''' This object gives access to Vectors in Blender. :param seq: Components of the vector, must be a sequence of at least two :type seq: sequence of numbers
@@ -2266,22 +1972,22 @@ class Vector:
         '''
         pass
 
-    def cross(self, other: 'Vector') -> 'Vector':
+    def cross(self, other: 'Vector') -> typing.Union[float, 'Vector']:
         ''' Return the cross product of this vector and another.
 
         :param other: The other vector to perform the cross product with.
         :type other: 'Vector'
-        :rtype: 'Vector'
+        :rtype: typing.Union[float, 'Vector']
         :return: The cross product.
         '''
         pass
 
-    def dot(self, other: 'Vector') -> 'Vector':
+    def dot(self, other: 'Vector') -> float:
         ''' Return the dot product of this vector and another.
 
         :param other: The other vector to perform the dot product with.
         :type other: 'Vector'
-        :rtype: 'Vector'
+        :rtype: float
         :return: The dot product.
         '''
         pass
@@ -2388,11 +2094,11 @@ class Vector:
         pass
 
     @staticmethod
-    def rotate(other: 'Euler'):
+    def rotate(other: typing.Union['Quaternion', 'Matrix', 'Euler']):
         ''' Rotate the vector by a rotation value.
 
         :param other: rotation component of mathutils value
-        :type other: 'Euler'
+        :type other: typing.Union['Quaternion', 'Matrix', 'Euler']
         '''
         pass
 
@@ -2458,12 +2164,12 @@ class Vector:
         '''
         pass
 
-    def to_tuple(self, precision: int = -1) -> typing.Tuple:
+    def to_tuple(self, precision: int = -1) -> tuple:
         ''' Return this vector as a tuple with.
 
         :param precision: The number to round the value to in [-1, 21].
         :type precision: int
-        :rtype: typing.Tuple
+        :rtype: tuple
         :return: the values of the vector rounded by *precision*
         '''
         pass
@@ -2479,138 +2185,3 @@ class Vector:
 
         '''
         pass
-
-    def __add__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __sub__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __mul__(self, other: typing.Union[int, float]) -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __truediv__(self, other: typing.Union[int, float]) -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __matmul__(self, other: 'Matrix') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __radd__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __rsub__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __rmul__(self, other: typing.Union[int, float]) -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __rtruediv__(self, other: typing.Union[int, float]) -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __rmatmul__(self, other: 'Matrix') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __iadd__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __isub__(self, other: 'Vector') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Vector'
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __imul__(self, other: typing.Union[int, float]) -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __itruediv__(self, other: typing.Union[int, float]) -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: typing.Union[int, float]
-        :rtype: 'Vector'
-        '''
-        pass
-
-    def __imatmul__(self, other: 'Matrix') -> 'Vector':
-        ''' 
-
-        :param other: 
-        :type other: 'Matrix'
-        :rtype: 'Vector'
-        '''
-        pass
